Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(145)

Unified Diff: tests/PDFDeflateWStreamTest.cpp

Issue 1316233002: Style Change: NULL->nullptr (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: 2015-08-27 (Thursday) 10:25:06 EDT Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tests/OSPathTest.cpp ('k') | tests/PDFDocumentTest.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tests/PDFDeflateWStreamTest.cpp
diff --git a/tests/PDFDeflateWStreamTest.cpp b/tests/PDFDeflateWStreamTest.cpp
index a85212c2c30a1ed376729392aa1a9950345ac783..f4d8dd3730e40955bb86e03a344ac7323987bd28 100644
--- a/tests/PDFDeflateWStreamTest.cpp
+++ b/tests/PDFDeflateWStreamTest.cpp
@@ -27,7 +27,7 @@ void skia_free_func(void*, void* address) { sk_free(address); }
/**
* Use the un-deflate compression algorithm to decompress the data in src,
* returning the result. Returns NULL if an error occurs.
*/
SkStreamAsset* stream_inflate(SkStream* src) {
SkDynamicMemoryWStream decompressedDynamicMemoryWStream;
@@ -39,8 +39,8 @@ SkStreamAsset* stream_inflate(SkStream* src) {
z_stream flateData;
flateData.zalloc = &skia_alloc_func;
flateData.zfree = &skia_free_func;
- flateData.opaque = NULL;
- flateData.next_in = NULL;
+ flateData.opaque = nullptr;
+ flateData.next_in = nullptr;
flateData.avail_in = 0;
flateData.next_out = outputBuffer;
flateData.avail_out = kBufferSize;
@@ -51,8 +51,8 @@ SkStreamAsset* stream_inflate(SkStream* src) {
uint8_t* input = (uint8_t*)src->getMemoryBase();
size_t inputLength = src->getLength();
- if (input == NULL || inputLength == 0) {
- input = NULL;
+ if (input == nullptr || inputLength == 0) {
+ input = nullptr;
flateData.next_in = inputBuffer;
flateData.avail_in = 0;
} else {
@@ -73,7 +73,7 @@ SkStreamAsset* stream_inflate(SkStream* src) {
if (rc != Z_OK)
break;
if (flateData.avail_in == 0) {
- if (input != NULL)
+ if (input != nullptr)
break;
size_t read = src->read(&inputBuffer, kBufferSize);
if (read == 0)
@@ -27,7 +27,7 @@ void skia_free_func(void*, void* address) { sk_free(address); }
/**
* Use the un-deflate compression algorithm to decompress the data in src,
- * returning the result. Returns NULL if an error occurs.
+ * returning the result. Returns nullptr if an error occurs.
*/
SkStreamAsset* stream_inflate(SkStream* src) {
« no previous file with comments | « tests/OSPathTest.cpp ('k') | tests/PDFDocumentTest.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698